@@ -4,7 +4,8 @@ from functools import wraps
 from flask import Flask
 import pytest
 
-from sqlalchemy_handler import db
+from sqlalchemy_handler import Handler
+from tests.utils.db import db
 from tests.utils.install_models import install_models
 
 @pytest.fixture(scope='session')
@@ -15,7 +16,7 @@ def app():
     app.config['SQLALCHEMY_TRACK_MODIFICATIONS'] = False
     app.config['TESTING'] = True
     db.init_app(app)
-
+    Handler.set_db(db)
     app.app_context().push()
     install_models()
 
