@@ -1,6 +1,6 @@
 from sqlalchemy import orm
 
-from sqlalchemy_handler.db import db
+from tests.utils.db import db
 from tests.utils.activity import create_index_activity_if_not_exists, \
                                  create_versionning_tables
 
